@@ -6,8 +6,7 @@ sub Webqq::Client::_send_sess_message{
     my $msg_origin = dclone($msg);
     $msg->{$_} = decode("utf8",$msg->{$_} ) for keys %$msg;
     my $ua = $self->{asyn_ua};
-    my $send_message_callback = $msg->{cb};
-    ref $cb eq 'CODE'?$send_message_callback = $cb:$send_message_callback = $self->{on_send_message};
+    my $send_message_callback = $msg->{cb} || $self->{on_send_message};
     my $callback = sub{
         my $response = shift;
         print $response->content() if $self->{debug};
